summaryrefslogtreecommitdiff
path: root/src/defines.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/defines.h')
-rw-r--r--src/defines.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/defines.h b/src/defines.h
index a3a7e2f9..7a93f02f 100644
--- a/src/defines.h
+++ b/src/defines.h
@@ -192,7 +192,8 @@ enum {
PGMSG_USE_ITEM = 0x0300, // B slot
GPMSG_USE_RESPONSE = 0x0301, // B error
GPMSG_BEINGS_DAMAGE = 0x0310, // { W being id, W amount }*
- GPMSG_CREATE_EFFECT = 0x0320, // W effect id, W*2 position
+ GPMSG_CREATE_EFFECT_POS = 0x0320, // W effect id, W*2 position
+ GPMSG_CREATE_EFFECT_BEING = 0x0321, // W effect id, W BeingID
// Guild
PCMSG_GUILD_CREATE = 0x0350, // S name